@@ -6,7 +6,7 @@ C R port: copyright 1998-2002 by Roger S. Bivand
 
       implicit real*8(a-h,o-z)
 
-      include 'bounds.cmn'
+      include 'bounds.h'
 
       dimension x(n),y(n),xp(np+1),yp(np+1),s(ns),hkhat(ns)
       dimension icounts(nptns), hkhats(nptns)
